@@ -1,4 +1,10 @@
-__version__ = "0.0.8"
+__version__ = "0.0.10"
+
+import kappadata.caching
+import kappadata.copying
+import kappadata.datasets
+import kappadata.loading
+import kappadata.wrappers
 
 from .caching.redis_dataset import RedisDataset
 from .caching.shared_dict_dataset import SharedDictDataset
